@@ -74,12 +74,16 @@ uv_stream_t* createPipeServer(uv_loop_t* pLoop, const std::string& name,
     umask(oldMask);
 
   if (r) {
-    delete (boost::shared_ptr<Socket>*)pSocket->handle.stream.data;
+    err_printf("createPipeServer: %s\n", uv_strerror(r));
+    // It's important that close() is explicitly called, so that the uv_pipe_t is cleaned up
+    pSocket->close();
     return NULL;
   }
   r = uv_listen((uv_stream_t*)&pSocket->handle.stream, 128, &on_request);
   if (r) {
-    delete (boost::shared_ptr<Socket>*)pSocket->handle.stream.data;
+    err_printf("createPipeServer: %s\n", uv_strerror(r));
+    // It's important that close() is explicitly called, so that the uv_pipe_t is cleaned up
+    pSocket->close();
     return NULL;
   }
 
@@ -127,11 +131,11 @@ uv_stream_t* createTcpServer(uv_loop_t* pLoop, const std::string& host,
   struct sockaddr_in6 addr6;
   struct sockaddr_in  addr4;
   sockaddr* pAddress;
-  int ip_family = ipFamily(host);
-  if (ip_family == AF_INET6) {
+  int family = ip_family(host);
+  if (family == AF_INET6) {
     r = uv_ip6_addr(host.c_str(), port, &addr6);
     pAddress = reinterpret_cast<sockaddr*>(&addr6);
-  } else if (ip_family == AF_INET){
+  } else if (family == AF_INET){
     r = uv_ip4_addr(host.c_str(), port, &addr4);
     pAddress = reinterpret_cast<sockaddr*>(&addr4);
   } else {
@@ -140,6 +144,7 @@ uv_stream_t* createTcpServer(uv_loop_t* pLoop, const std::string& host,
   }
 
   if (r) {
+    err_printf("createTcpServer: %s\n", uv_strerror(r));
     // It's important that close() is explicitly called, so that the uv_tcp_t is cleaned up
     pSocket->close();
     return NULL;
@@ -148,12 +153,14 @@ uv_stream_t* createTcpServer(uv_loop_t* pLoop, const std::string& host,
   r = uv_tcp_bind(&pSocket->handle.tcp, pAddress, 0);
 
   if (r) {
+    err_printf("createTcpServer: %s\n", uv_strerror(r));
     // It's important that close() is explicitly called, so that the uv_tcp_t is cleaned up
     pSocket->close();
     return NULL;
   }
   r = uv_listen((uv_stream_t*)&pSocket->handle.stream, 128, &on_request);
   if (r) {
+    err_printf("createTcpServer: %s\n", uv_strerror(r));
     // It's important that close() is explicitly called, so that the uv_tcp_t is cleaned up
     pSocket->close();
     return NULL;
